@@ -24,6 +24,7 @@ log = logging.getLogger(__name__)
 import math
 from collections import defaultdict
 from typing import (
+    TYPE_CHECKING,
     Any,
     Callable,
     Iterable,
@@ -36,9 +37,6 @@ from typing import (
     overload,
 )
 
-# External imports
-from typing_extensions import TypeAlias
-
 # Bokeh imports
 from .core.enums import Location, LocationType, SizingModeType
 from .models import (
@@ -61,6 +59,9 @@ from .models import (
 )
 from .util.dataclasses import dataclass
 
+if TYPE_CHECKING:
+    from typing_extensions import TypeAlias
+
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
